ActiveInstance

Struct ActiveInstance 

pub struct ActiveInstance {
    pub instance_health: Option<String>,
    pub instance_id: Option<String>,
    pub instance_type: Option<String>,
    pub spot_instance_request_id: Option<String>,
}
Describes a running instance in a Spot Fleet.

Fields

instance_health: Option<String>

The health status of the instance. If the status of either the instance status check or the system status check is impaired, the health status of the instance is unhealthy. Otherwise, the health status is healthy.

instance_id: Option<String>

The ID of the instance.

instance_type: Option<String>

The instance type.

spot_instance_request_id: Option<String>

The ID of the Spot Instance request.