pub struct ConnectionLogResponseOptions {
pub cloudwatch_log_group: Option<String>,
pub cloudwatch_log_stream: Option<String>,
pub enabled: Option<bool>,
}Expand description
Information about the client connection logging options for a Client VPN endpoint.
Fields
cloudwatch_log_group: Option<String>The name of the Amazon CloudWatch Logs log group to which connection logging data is published.
cloudwatch_log_stream: Option<String>The name of the Amazon CloudWatch Logs log stream to which connection logging data is published.
enabled: Option<bool>Indicates whether client connection logging is enabled for the Client VPN endpoint.